#
# spec file for package cdk
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname lib%{name}%(set -- $(tar --wildcards -Oxf %{S:0} '*/VERSION'|sed -r 's/:/_/g'); echo $1)
%define mainver 5.0
%define datever 20230201

Name:           cdk
URL:            https://invisible-island.net/cdk/
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
Version:        %{mainver}.%{datever}
Release:        1.5
Summary:        The Runtime for the Curses Development Kit
License:        BSD-3-Clause
Group:          System/Libraries
Source0:        https://www.invisible-island.net/archives/%{name}/%{name}-%{mainver}-%{datever}.tgz
Source1:        https://www.invisible-island.net/archives/%{name}/%{name}-%{mainver}-%{datever}.tgz.asc
Source2:        %name.keyring
%global root    %{_tmppath}/%{name}-%{version}-store

%description
CDK is a widget set developed on top of the basic curses library. It
contains 21 ready to use widgets, some of which are: a text entry
field, a scrolling list, a selection list, an alphalist, a pull-down
menu, a radio list, a viewer widget, and a dialog box.

%package -n %lname
Summary:        The Runtime for the Curses Development Kit - Shared library
Group:          Development/Libraries/C and C++
Conflicts:      libcdk5
Conflicts:      libcdk6_2_4

%description -n %lname
CDK is a widget set developed on top of the basic curses library. It
contains 21 ready to use widgets, some of which are: a text entry
field, a scrolling list, a selection list, an alphalist, a pull-down
menu, a radio list, a viewer widget, and a dialog box.

%package devel
Summary:        Development Part of Curses Development Kit
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       ncurses-devel

%description devel
This package includes the development headers and static libraries for
CDK, the Curses Development Kit.

%prep
%setup -q -n cdk-%{mainver}-%{datever}

%build
%configure --with-ncurses	\
    --enable-const		\
    --with-pkg-config		\
    --disable-rpath-hack	\
    --with-versioned-syms=${PWD}/package/cdk.map \
    --with-shared
%make_build
make install DESTDIR=%{root} INSTALL="install -pD" \
    DOCUMENT_DIR=%{root}%{_defaultdocdir}/%{name}
make clean

%configure --with-ncursesw	\
    --enable-const		\
    --with-pkg-config		\
    --disable-rpath-hack	\
    --with-versioned-syms=${PWD}/package/cdk.map \
    --with-cfgname=cdkw		\
    --with-libname=cdkw		\
    --with-shared
%make_build
make installCDKLibrary DESTDIR=%{root} INSTALL="install -pD" \
    DOCUMENT_DIR=%{root}%{_defaultdocdir}/%{name}
make %{root}%{_libdir}/libcdkw.so.%{mainver} DESTDIR=%{root}

%install
tar -cpf - -C %{root} . | tar -xpf - -C %{buildroot}
%if %{defined license}
rm -vf %{buildroot}%{_defaultdocdir}/%{name}/COPYING
%endif
# fixes rpmlint unstripped-binary-or-object
chmod +x %{buildroot}%{_libdir}/*.so
find %{buildroot} -name '*.a' -delete -print
# Remove installed in wrong directory documentation files
rm -rf %{buildroot}%{_datadir}/doc

%post -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%if %{defined license}
%license COPYING
%doc README CHANGES VERSION
%else
%doc README CHANGES VERSION COPYING
%endif
%{_libdir}/libcdk*.so.*

%files devel
%{_bindir}/cdk*5-config
%{_libdir}/libcdk*.so
%{_includedir}/%{name}
%{_includedir}/%{name}.h
%{_mandir}/man1/*.1%{ext_man}
%{_mandir}/man3/*.3%{ext_man}

%changelog
* Fri Jun 23 2023 Dr. Werner Fink <werner@suse.de>
- Let libcdk6_3_4 conflict with older libcdk6_2_4
* Fri Jun 23 2023 Dr. Werner Fink <werner@suse.de>
- Update to version 5.0.20230201
  + improve compiler-warnings in configure-checks.
  + change library dependencies in rpm spec-file.
  + update license in test-packages.
  + relicense as MIT-X11
  + reduce shellcheck warnings in support-scripts
  + updated configure script to work around regression in GNU grep 3.8
  + updated configure macros from xterm and ncurses development
  + update config.guess, config.sub
  + fix cppcheck style-warnings.
  + improve makefile header-dependencies by accounting for all generated
    headers (report/patch by Sergei Trofimovich).
  + updated configure macros from xterm and ncurses development:
    CF_ADD_INCDIR CF_APPEND_CFLAGS CF_DISABLE_ECHO CF_MAKEFLAGS
    CF_NCURSES_CONFIG CF_NCURSES_LIBS CF_PKG_CONFIG CF_REMOVE_CFLAGS
    CF_SHARED_OPTS CF_TRY_XOPEN_SOURCE CF_XOPEN_SOURCE
  + build-fix for HP-UX curses, which provides only part of the ACS_xxx
    definitions compatible with chtype's.
  + correct calls on SetViewSize in scroll.c, overlooked in 2005/04/24
    (report by Brad Hines).
  + updated configure macros from xterm and ncurses development:
    CF_C11_NORETURN CF_CHECK_LIBTOOL_VERSION CF_CONST_X_STRING
    CF_DISABLE_LEAKS CF_FUNC_LSTAT CF_GETOPT_HEADER CF_NCURSES_CONFIG
    CF_NO_LEAKS_OPTION CF_SHARED_OPTS CF_UTF8_LIB CF_XOPEN_CURSES
    CF_XOPEN_SOURCE
  + update config.guess, config.sub
  + updated configure script, for _Noreturn and exit_curses checks.
  + spelling fixes, per codespell.
  + updated configure script, for quoting/escaping fixes
  + update config.guess, config.sub
  + updated configure script, for compiler-warnings
  + update config.guess, config.sub
  + updated configure script, to work around ncurses 6.2 vs xcode's c99
    "-W" option.
  + update config.guess, config.sub
  + fix issues found with check-manpage
  + updated configure macros, from xterm and ncurses development:
    CF_ADD_LIBS CF_GCC_VERSION CF_GCC_WARNINGS CF_PROG_CC CF_PROG_LINT
    CF_X_TOOLKIT
  + update config.guess, config.sub
* Tue Apr 26 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "libcdk5.x86_64: E:
  shlib-policy-name-error SONAME: libcdk.so.6.2.4, expected
  package suffix: 6_2_4"
* Mon May  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.0.20210324
  * Spelling fixes, per codespell
  * Updated build system
* Tue Mar  5 2019 Dr. Werner Fink <werner@suse.de>
- Update to version 5.0.20190303
  + deprecate installCDKLibrary rule by install.libs, which is used in
    the newer shared-library macros.
  + conditionally-comment action lines for the part of install-rules
    which conflict with the newer shared-library rules (report by Tom
    Brownridge).
* Wed Feb 27 2019 Dr. Werner Fink <werner@suse.de>
- Remove debugging code from spec file
* Tue Feb 26 2019 Dr. Werner Fink <werner@suse.de>
- Update to version 5.0.20190224
  + use HDR_ROOTNAME rather than PACKAGE in top-level makefile, to
    simplify building cdk and cdkw packages with non-conflicting paths.
  + add "check" rule to top-level makefile, for testing Arch Linux
    package.
  + modify test-package for RPMs to work with SUSE and Mageia.
- Enable wide version of libcdk(w)
- Enable ABI soname of the shared libraries
  + Somehow strange ABI 6.2.4 but RELEASE version is still 5.0
* Fri Feb 22 2019 Dr. Werner Fink <werner@suse.de>
- Update to version 5.0.20190220
  * 2019/02/20
    + updated rpm spec-file, for test-builds.
    + added pkgsrc files, for test-builds.
    + updated FreeBSD port-files, for test-builds.
    + add getCdkTitle, which uses new display encoding "<#10>" for newline
    in the example which demonstrates it, mentry_ex2 (prompted by
    discussion with Stéphane Goujet).
    + fix similar memory leaks in setCDKRadioItems and setCDKSelectionItems
    + fix memory leak in setCDKScrollItems (report by Stéphane Goujet).
    + make functionKey parameter to getchCDKObject optional
    (suggested by Stéphane Goujet).
    + modify test-packages to adjust includes in cdk.h when using test
    package for ncurses6 which would confuse test-package for cdk-perl.
    + change shlib-version in test-package to "abi", for better
    compatibility with the test-package for cdk-perl.
    + add manpage for cdk5-config
    + documentation improvements (report by Stéphane Goujet).
    + add check in drawCDKScrollCurrent() in case the list is not
    initialized (report by Stéphane Goujet).
    + modify writeCharAttrib to replace the color in the target cell rather
    than OR'ing it from the source-attribute (patch by Aarian P. Aleahmad)
    + add a null-pointer check in viewer.c's PatternNotFound() function
    (report by "c").
    + improve macros/markup in manpages.
    + updated configure macros, from lynx and ncurses development:
    CF_ADD_INCDIR, CF_CC_ENV_FLAGS, CF_CURSES_CPPFLAGS, CF_CURSES_LIBS,
    CF_FIND_LINKAGE, CF_GCC_WARNINGS, CF_GNU_SOURCE, CF_LD_RPATH_OPT,
    CF_NCURSES_CONFIG, CF_PDCURSES_X11, CF_POSIX_C_SOURCE, CF_PROG_EXT,
    CF_SHARED_OPTS, CF_TRY_XOPEN_SOURCE, CF_WITH_VERSIONED_SYMS,
    CF_XOPEN_CURSES, CF_XOPEN_SOURCE, CF_X_ATHENA_CPPFLAGS
    + update config.guess, config.sub
  * 2018/03/06
    + update versioned-symbol list for reRegisterCDKObject (prompted by
    Debian #892114, which adopted a different set of symbol versions
    such as "5.0.20161120", cf: 2014/11/06).
    + updated configure macros, from lynx development:  CF_CURSES_FUNCS,
    CF_CURSES_LIBS, CF_MAKEFLAGS, CF_NCURSES_CONFIG, CF_SHARED_OPTS
    + update config.guess, config.sub
  * 2017/12/09
    + updated ftp url in test-packages, etc.
    + updated configure macros CF_CC_ENV_FLAGS, CF_SHARED_OPTS
    + update config.guess, config.sub
  * 2017/09/18
    + updated configure macros:
    + CF_ADD_CFLAGS improve formatting of generated lists using
    CF_APPEND_TEXT
    + CF_CC_ENV_FLAGS - two changes
    a) revise the expression generating $cf_flags to actually work when
    there is more than one option.
    b) correct the parameter passed to CF_ADD_CFLAGS, which was the
    whole list rather than the current parameter.
    + CF_CURSES_LIBS reorganize to handle the case where initscr is a
    macro.
    + CF_NCURSES_CONFIG add check for term.h when using pkg-config
    + CF_NCURSES_VERSION use prototype for main
    + CF_SHARED_OPTS workaround for PGI compiler
    + CF_WITH_LIBTOOL use SIGQUIT(3) rather than SIGTRAP(5) in trap
    commands.  Fix a few places in configure/build scripts where
    DESTDIR and rpath were combined.
    + update config.guess, config.sub
  * 2016/12/10
    + improve formatting of manpages, using bullets
    + add -C and -R options to matrix_ex.c to exercise the col/row spacing
    features of matrix widget.
    + modify matrix widget to highlight the current cell for the cases
    when col/row spacing are greater than zero.
  * 2016/12/04
    + cleanup change for color pairs in 2016/11/20
    + modify initCDKScreen() to simplify initialization of curses by
    calling initscr() in this function after initializing the locale.
    That fixes a problem using PuTTY with CDK when built using ncurses
    (report by Marc Smith).
  * 2016/11/20
    + fix warnings from cppcheck 1.76.1
    + updated configure macros:
    + CF_CC_ENV_FLAGS don't limit the check to -I, -U and -D options,
    since the added options can include various compiler options before
    and after preprocessor options.
    + CF_GNU_SOURCE recent glibc (Debian 2.23-4 for example) has
    misordered ifdef/checks for new symbol _DEFAULT_SOURCE, producing
    warning messages when only _GNU_SOURCE is defined.  Add a followup
    check to define _DEFAULT_SOURCE.
    + CF_LD_RPATH_OPT change FreeBSD to use -Wl,-rpath rather than -rpath
    option.  According to FreeBSD #178732, either works since FreeBSD
    4.x; however scons does not accept anything except the -Wl,-rpath
    form.
    + CF_PROG_LINT add cpplint to programs to use; drop ad hoc tdlint and
    alint.
    + CF_WITH_NCURSES_ETC add check for ncurses pthreads
    + CF_XOPEN_SOURCE add "uclinux" to list of Linux's and use
    _GNU_SOURCE for cygwin headers, tested with cygwin 2.3, 2.5
    + CF__ADD_SHLIB_RULES improve scripting for ldconfig to avoid warning
    messages if no permissions
    + update config.guess, config.sub
    > patches by Aarian P. Aleahmad:
    + modify encodeAttribute() to allow up to 256 color pairs.
    + corrected assignment in scroller_SetPosition(), to show highlighted
    member.
    + improve the way attributes are applied to Mentry widgets.
    + improve Entry widget by using newwin rather than subwin, as well
    as passing arguments to callback function.
  * 2016/11/19
    + add reRegisterCDKObject()
  * 2016/01/31
    + fix a few of the lintian errors in package/debian
    + fix some too-wide tables in manpages, which caused Debian lintian
    errors.
    + take lower-limit's formatted length into account in slider, etc.,
    (patch by Guido Meusch).
    + make similar repainting-fixes for radio.c and marquee.c
    + fix repainting of Scroll widget when it has no box-outline
    (patch by Manuel Schmitz).
    + add highlight and callbackData members to CDKBUTTON, as well as
    macros for setting/getting the highlight value.  Use the highlight to
    override the default A_REVERSE used in CDK button (patch by Aarian P.
    Aleahmad).
    + fix two bugs in template.c (patch by Aarian P. Aleahmad):
    + in cleanCDKTemplate, fill all of the info string with nulls
    + in setCDKTemplateValue, call cleanCDKTemplate whether or not
    the pointer for newValue passed by the caller was a null.
    + updated configure macros:
    + CF_LIB_PREFIX, CF_WITH_LIBTOOL, and CF_XOPEN_SOURCE, build-fixes
    for OS/2
    + CF_XOPEN_CURSES, improve check, making it define NCURSES_WIDECHAR
    if we happen to be building on a platform (such as OSX) where we do
    not define _XOPEN_SOURCE or _XOPEN_SOURCE_EXTENDED
    + CF_WITH_VERSIONED_SYMS, avoid ncurses build error on ppc64
    architecture the nm tool is reporting _is_missing in Data section
    for ppc64 (by comparison ppc64le is reporting it in Text section)
    + update config.guess, config.sub
  * 2015/09/28
    + build ".deb" test-package with ncurses6, using versioned symbols.
    + updated configure macros:
    + modifications from ncurses/xterm to allow alternate to /bin/sh for
    configure-shell, while dropping support for non-POSIX shell such
    as Solaris.
    + updated/integrated changes for versioned symbols from ncurses6.
    + CF_DISABLE_LIBTOOL_VERSION when using -version-info (the native
    libtool mode), get the ABI_VERSION value from $VERSION (which comes
    from CF_VERSION_INFO)
    + CF_ADD_INCDIR fix an infinite loop when the include-directory to be
    added does not exist (Debian #786436)
    + CF_WITH_NCURSES_ETC add --with-screen option
    + CF_SUBDIR_PATH change this to a loop, adding /usr/pkg (NetBSD) and
    /opt/local (Mac OSX)
    + update config.guess, config.sub
  * 2015/01/03
    + modify cdk-config.in to work with systems where libdir is /usr/lib64
    (patch by Peter Hyman).
    + corrected example for cdk_display.3 manpage (patch by Loïc
    work in non-POSIX locales (report by Mart Stöör).
* Sun Nov  1 2015 p.drouand@gmail.com
- Update to version 5.0.20150928
  * build ".deb" test-package with ncurses6, using versioned symbols.
  * modifications from ncurses/xterm to allow alternate to /bin/sh for
    configure-shell, while dropping support for non-POSIX shell such
    as Solaris.
  * updated/integrated changes for versioned symbols from ncurses6.
  * CF_DISABLE_LIBTOOL_VERSION when using -version-info (the native
    libtool mode), get the ABI_VERSION value from $VERSION (which comes
    from CF_VERSION_INFO)
  * CF_ADD_INCDIR fix an infinite loop when the include-directory to be
    added does not exist (bdo#786436)
  * CF_WITH_NCURSES_ETC add --with-screen option
  * CF_SUBDIR_PATH change this to a loop, adding /usr/pkg (NetBSD) and
    /opt/local (Mac OSX)
  * update config.guess, config.sub
* Mon Dec 29 2014 meissner@suse.com
- fixed url, added .asc and keyring
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 5.0.20141106
  + Too many things to list; please read the changelog file
- Cleanup specfile
- Split out cdk library to a lib subpackage
- Update Url and source download Url
- Remove obsolete cdk-4.9.13.dif
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri Feb 19 2010 coolo@novell.com
- fix compilation with gcc 4.5
* Sun Aug 30 2009 coolo@novell.com
- use %%patch for Patch
* Sun Mar  8 2009 crrodriguez@suse.de
- remove static libraries
* Thu Mar 29 2007 meissner@suse.de
- added ncurses-devel
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 23 2004 werner@suse.de
- Add cdk to required packages for cdk-devel (bug #48405)
- Update to cdk 4.9.13
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Wed Jan  8 2003 werner@suse.de
- cdk-devel requires ncurses-devel (bug# 20065)
* Tue Apr 30 2002 sf@suse.de
- changed paths to %%{_libdir}
* Mon Apr  8 2002 ro@suse.de
- call autoreconf
* Wed Nov 14 2001 werner@suse.de
- New package cdk (Curses Development Kit) which provides an
  easy interface for programmers to (n)curses.  Is used e.g.
  by curses based programs like ntuxzap from DVB driver package.
